@@ -85,6 +85,51 @@ def parse_irr_as_set(asn: int, irr_as_set: str) -> list[tuple[str, str]]:
     return as_sets
 
 
+def build_irr_as_set_command(
+    as_set: str,
+    source: str = "",
+    address_family: Literal[4, 6] = 6,
+    irr_sources_override: str = "",
+    irr_ipv6_prefixes_args_override: str = "",
+    irr_ipv4_prefixes_args_override: str = "",
+) -> list[str]:
+    """
+    Build the command to expand the given AS-SET for an IP version.
+    """
+    if _is_using_bgpq4() and settings.BGPQ4_KEEP_SOURCE_IN_SET and source:
+        as_set = f"{source}:{as_set}"
+
+    # Set the arguments to pass to bgpq3/bgpq4
+    command_args: list[str] = []
+    if address_family == 6:
+        if irr_ipv6_prefixes_args_override:
+            command_args = irr_ipv6_prefixes_args_override.split()
+        elif settings.BGPQ3_ARGS and "ipv6" in settings.BGPQ3_ARGS:
+            command_args = settings.BGPQ3_ARGS["ipv6"]
+    if address_family == 4:
+        if irr_ipv4_prefixes_args_override:
+            command_args = irr_ipv4_prefixes_args_override.split()
+        elif settings.BGPQ3_ARGS and "ipv4" in settings.BGPQ3_ARGS:
+            command_args = settings.BGPQ3_ARGS["ipv4"]
+
+    # Call bgpq with arguments to get a JSON result;
+    # only include option if argument is not null
+    command: list[str] = [settings.BGPQ3_PATH]
+
+    # Set host to query
+    if settings.BGPQ3_HOST:
+        command += ["-h", settings.BGPQ3_HOST]
+
+    # Set sources to query
+    if irr_sources_override:
+        command += ["-S", irr_sources_override]
+    elif settings.BGPQ3_SOURCES:
+        command += ["-S", settings.BGPQ3_SOURCES]
+
+    command += [f"-{address_family}", *command_args, "-j", "-l", "prefix_list", as_set]
+    return command
+
+
 def call_irr_as_set_resolver(
     as_set: str,
     source: str = "",
@@ -99,37 +144,14 @@ def call_irr_as_set_resolver(
     if not as_set:
         return []
 
-    if _is_using_bgpq4() and settings.BGPQ4_KEEP_SOURCE_IN_SET and source:
-        as_set = f"{source}:{as_set}"
-
-    # Set the arguments to pass to bgpq3/bgpq4
-    command_args = []
-    if address_family == 6:
-        if irr_ipv6_prefixes_args_override:
-            command_args = irr_ipv6_prefixes_args_override.split()
-        elif settings.BGPQ3_ARGS and "ipv6" in settings.BGPQ3_ARGS:
-            command_args = settings.BGPQ3_ARGS["ipv6"]
-    if address_family == 4:
-        if irr_ipv4_prefixes_args_override:
-            command_args = irr_ipv4_prefixes_args_override.split()
-        elif settings.BGPQ3_ARGS and "ipv4" in settings.BGPQ3_ARGS:
-            command_args = settings.BGPQ3_ARGS["ipv4"]
-
-    # Call bgpq with arguments to get a JSON result;
-    # only include option if argument is not null
-    command = [settings.BGPQ3_PATH]
-
-    # Set host to query
-    if settings.BGPQ3_HOST:
-        command += ["-h", settings.BGPQ3_HOST]
-
-    # Set sources to query
-    if irr_sources_override:
-        command += ["-S", irr_sources_override]
-    elif settings.BGPQ3_SOURCES:
-        command += ["-S", settings.BGPQ3_SOURCES]
-
-    command += [f"-{address_family}", *command_args, "-j", "-l", "prefix_list", as_set]
+    command = build_irr_as_set_command(
+        as_set=as_set,
+        source=source,
+        address_family=address_family,
+        irr_sources_override=irr_sources_override,
+        irr_ipv6_prefixes_args_override=irr_ipv6_prefixes_args_override,
+        irr_ipv4_prefixes_args_override=irr_ipv4_prefixes_args_override,
+    )
 
     try:
         out = _call_bgpq_binary(command)
@@ -143,6 +165,30 @@ def call_irr_as_set_resolver(
     return list(json.loads(out)["prefix_list"])
 
 
+def build_irr_as_set_as_list_command(
+    first_as: int, as_set: str, source: str = "", irr_sources_override: str = ""
+) -> list[str]:
+    """
+    Build the command to expand the given AS-SET into an AS list.
+    """
+    if _is_using_bgpq4() and settings.BGPQ4_KEEP_SOURCE_IN_SET and source:
+        as_set = f"{source}::{as_set}"
+
+    # Set host to query
+    command: list[str] = [settings.BGPQ3_PATH]
+    if settings.BGPQ3_HOST:
+        command += ["-h", settings.BGPQ3_HOST]
+
+    # Set sources to query
+    if irr_sources_override:
+        command += ["-S", irr_sources_override]
+    elif settings.BGPQ3_SOURCES:
+        command += ["-S", settings.BGPQ3_SOURCES]
+
+    command += ["-j", "-l", "as_list", "-f", str(first_as), as_set]
+    return command
+
+
 def call_irr_as_set_as_list_resolver(
     first_as: int, as_set: str, source: str = "", irr_sources_override: str = ""
 ) -> list[int]:
@@ -157,18 +203,12 @@ def call_irr_as_set_as_list_resolver(
     if _is_using_bgpq4() and settings.BGPQ4_KEEP_SOURCE_IN_SET and source:
         as_set = f"{source}::{as_set}"
 
-    # Set host to query
-    command = [settings.BGPQ3_PATH]
-    if settings.BGPQ3_HOST:
-        command += ["-h", settings.BGPQ3_HOST]
-
-    # Set sources to query
-    if irr_sources_override:
-        command += ["-S", irr_sources_override]
-    elif settings.BGPQ3_SOURCES:
-        command += ["-S", settings.BGPQ3_SOURCES]
-
-    command += ["-j", "-l", "as_list", "-f", str(first_as), as_set]
+    command = build_irr_as_set_as_list_command(
+        first_as=first_as,
+        as_set=as_set,
+        source=source,
+        irr_sources_override=irr_sources_override,
+    )
 
     try:
         out = _call_bgpq_binary(command)
