@@ -6,7 +6,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.test import TestCase
 
 from bgp.enums import CommunityType
-from bgp.models import Community
+from bgp.models import Community, Relationship
 from devices.enums import DeviceStatus
 from devices.models import Configuration, Router
 from extras.models import ExportTemplate, Tag
@@ -16,6 +16,7 @@ from net.models import Connection
 from peering.enums import BGPGroupStatus, BGPSessionStatus, IPFamily
 from peering.models import (
     AutonomousSystem,
+    DirectPeeringSession,
     InternetExchange,
     InternetExchangePeeringSession,
     RoutingPolicy,
@@ -67,6 +68,7 @@ class Jinja2FilterTestCase(TestCase):
         ]
         Community.objects.bulk_create(cls.communities)
         AutonomousSystem.objects.create(asn=64520, name="Useless")
+        cls.local_as = AutonomousSystem.objects.create(asn=65534, name="Local")
         cls.a_s = AutonomousSystem.objects.create(
             asn=64510, name="Test", ipv6_max_prefixes=100
         )
@@ -145,6 +147,19 @@ class Jinja2FilterTestCase(TestCase):
         ContactAssignment.objects.create(
             object=cls.a_s, contact=cls.contact, role=cls.contact_role
         )
+        cls.relationship_customer = Relationship.objects.create(
+            name="Transit Customer", slug="transit-customer"
+        )
+        cls.relationship_peer = Relationship.objects.create(
+            name="Private Peer", slug="private-peer"
+        )
+        DirectPeeringSession.objects.create(
+            local_autonomous_system=cls.local_as,
+            autonomous_system=cls.a_s,
+            local_ip_address="192.0.2.100",
+            ip_address="192.0.2.101",
+            relationship=cls.relationship_customer,
+        )
 
     def test_ipv4(self):
         self.assertTrue(FILTER_DICT["ipv4"](self.session4.ip_address))
@@ -332,8 +347,15 @@ class Jinja2FilterTestCase(TestCase):
         self.assertEqual(6, FILTER_DICT["length"](RoutingPolicy.objects.all()))
         self.assertEqual(0, FILTER_DICT["length"](RoutingPolicy.objects.none()))
 
-    def test_cisco_password(self):
-        pass
+    def test_type7_password(self):
+        self.assertEqual(
+            "04480E051A33490C1E0F",
+            FILTER_DICT["cisco_password"]("7 04480E051A33490C1E0F"),
+        )
+        self.assertEqual(
+            "D5A81E1EF5D58A23",
+            FILTER_DICT["arista_password"]("7 D5A81E1EF5D58A23"),
+        )
 
     def test_iter_export_policies(self):
         self.assertListEqual(
@@ -433,7 +455,7 @@ class Jinja2FilterTestCase(TestCase):
         self.assertRaises(AttributeError, FILTER_DICT["connections"], self.a_s)
 
     def test_direct_sessions(self):
-        self.assertEqual(0, FILTER_DICT["direct_sessions"](self.a_s).count())
+        self.assertEqual(1, FILTER_DICT["direct_sessions"](self.a_s).count())
         self.assertEqual(0, FILTER_DICT["direct_sessions"](self.router).count())
 
     def test_ixp_sessions(self):
@@ -481,6 +503,38 @@ class Jinja2FilterTestCase(TestCase):
     def test_as_list(self):
         pass
 
+    def test_strip_irr_sources(self):
+        result = FILTER_DICT["strip_irr_sources"](self.a_s)
+        self.assertEqual(["AS64510"], result)
+
+        result = FILTER_DICT["strip_irr_sources"](
+            AutonomousSystem(
+                asn=64530, name="Test IRR", irr_as_set="RIPE::AS-TEST RADB:AS-OTHER"
+            )
+        )
+        self.assertEqual(sorted(["AS-TEST", "AS-OTHER"]), sorted(result))
+
+        result = FILTER_DICT["strip_irr_sources"](
+            AutonomousSystem(
+                asn=64531,
+                name="Test IRR Dup",
+                irr_as_set="RIPE::AS-EXAMPLE RADB:AS-EXAMPLE",
+            )
+        )
+        self.assertEqual(["AS-EXAMPLE"], result)
+
+        result = FILTER_DICT["strip_irr_sources"]("RIPE::AS-TEST")
+        self.assertEqual(["AS-TEST"], result)
+
+        result = FILTER_DICT["strip_irr_sources"]("RIPE::AS-EXAMPLE RADB:AS-EXAMPLE")
+        self.assertEqual(["AS-EXAMPLE"], result)
+
+        result = FILTER_DICT["strip_irr_sources"]("AS-PLAIN")
+        self.assertEqual(["AS-PLAIN"], result)
+
+        with self.assertRaises(ValueError):
+            FILTER_DICT["strip_irr_sources"](12345)
+
     def test_safe_string(self):
         self.assertEqual("Tele_a_ciu", FILTER_DICT["safe_string"]("Téle_à_çiu"))
 
@@ -629,3 +683,24 @@ class Jinja2FilterTestCase(TestCase):
         self.assertIn("export-deaggregated-v6", ipv6_slugs)
         self.assertIn("accept-all", ipv6_slugs)
         self.assertNotIn("export-deaggregated-v4", ipv6_slugs)
+
+    def test_relationships(self):
+        relationships = FILTER_DICT["relationships"](self.a_s)
+        self.assertEqual(1, relationships.count())
+        self.assertIn(self.relationship_customer, relationships)
+        self.assertNotIn(self.relationship_peer, relationships)
+
+        relationships_filtered = FILTER_DICT["relationships"](
+            self.a_s, local_autonomous_system=self.local_as
+        )
+        self.assertEqual(1, relationships_filtered.count())
+        self.assertIn(self.relationship_customer, relationships_filtered)
+
+        other_as = AutonomousSystem.objects.get(asn=64500)
+        relationships_other = FILTER_DICT["relationships"](
+            self.a_s, local_autonomous_system=other_as
+        )
+        self.assertEqual(0, relationships_other.count())
+
+        with self.assertRaises(ValueError):
+            FILTER_DICT["relationships"](self.ixp_connection)
